Terra class

Constructors

Terra({String? appName, String? clientId, TerraEnv? terraEnv, AppConfig? appConfig})

Properties

appConfig AppConfig?
getter/setter pair
appName String?
getter/setter pair
clientId String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraEnv TerraEnv?
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) Terra